@@ -1,5 +1,10 @@
 package MyApp::Types;
 
+use 5.14.0;
+
+use strict;
+use warnings;
+
 use Type::Library -base;
 use Type::Utils   -all;
 
